@@ -208,7 +208,7 @@ def main():
     argparse = ArgumentParser(prog="Chat room", description="This is a chat room for your mates")
     argparse.add_argument("-l", "--log", default="INFO", type=str, choices=["DEBUG", "INFO", "ERROR", "debug", "info", "error"])
     argparse.add_argument("-n", "--name", required=True, type=str)
-    argparse.add_argument("-a", "--addr", required=False, type=str)
+    argparse.add_argument("-a", "--addr", required=True, type=str)
     argparse.add_argument("-p", "--port", required=False, type=int)
     args = argparse.parse_args()
     
